import sys
import click
from mycolab.genbank import search as mycolab_search, split_sequence


@click.group()
@click.version_option("1.0.4")
def main():
    """Genbank search tool"""
    pass


@main.command()
@click.argument('sequence', required=True)
@click.option('--match', default=95.0, help='Minimum match accuracy')
@click.option('--results', default=50, help='Maximum results')
def search(**kwargs):
    """Search Genbank nucleotide database"""
    sequence = kwargs.get('sequence')
    min_match = kwargs.get('match')
    max_results = kwargs.get('results')
    fastas = mycolab_search(sequence, min_match=min_match, max_results=max_results)
    for fasta in fastas:
        print(f'>{fasta["description"]}')
        seq_lines = split_sequence(fasta.get('sequence'), max_line_len=80)
        for seq_line in seq_lines:
            print(seq_line)
        print()


if __name__ == '__main__':
    args = sys.argv
    if "--help" in args or len(args) == 1:
        print("mycolab")
    main()



import json
import logging
from redis import StrictRedis
from redis.exceptions import ConnectionError, ResponseError


def redis_client(host: str = 'redis', port: int = 6379, database: int = None, timeout: int = None) -> StrictRedis:
    """
    Redis client
    :return: client
    """
    try:
        client = StrictRedis(
            host=host,
            port=port,
            db=database,
            socket_timeout=timeout
        )
    except ConnectionError as e:
        logging.error(e)
        client = None

    return client


def set_value(key: str = None, value: dict = None, client: StrictRedis = None):
    """
    Set a value at key
    """
    response = None
    if key and value:
        try:
            response = client.execute_command('JSON.SET', key, '.', json.dumps(value))
        except ResponseError as e:
            logging.error(e)

    return response


def get_value(key: str = None, client: StrictRedis = None):
    """
    Get a value by key
    """
    response = None
    if key:
        try:
            response = json.loads(client.execute_command('JSON.SET', key))
        except ResponseError as e:
            logging.error(e)
    return response



import requests

SEARCH_URL = "http://34.121.111.173/v1/sequences"


def split_sequence(sequence: str, max_line_len: int = 80):
    line_len = 0
    read_chars = 0
    full_seq = list(sequence)
    seq_len = len(full_seq)
    seq_line = ''
    seq_lines = []

    while read_chars < seq_len:

        while line_len < max_line_len:

            if (len(full_seq) + line_len) <= max_line_len:
                seq_line += ''.join(full_seq)
                read_chars = seq_len
                break

            if len(full_seq) > 0:
                seq_line += full_seq.pop(0)
            else:
                break

            line_len = len(seq_line)
            read_chars += 1

        seq_lines.append(seq_line)
        line_len = 0
        seq_line = ''

    return seq_lines


def search(sequence: str, min_match: float = 95.0, max_results: int = 50):
    """
    Search MycoLab Genbank API
    :param sequence:
    :param min_match:
    :param max_results:
    :return:
    """

    data = {'location': True, 'match': min_match, 'results': max_results, "sequence": sequence}
    r = requests.post(SEARCH_URL, json=data)
    results = r.json()

    return results
